sentiment analysis using spacy pipelines

| Feature | Description |
| --- | --- |
| **Name** | `eng_spacysentiment` |
| **Version** | `2.2.0` |
| **spaCy** | `>=3.0.9,<3.1.0` |
| **Default Pipeline** | `textcat` |
| **Components** | `textcat` |
| **Vectors** | 0 keys, 0 unique vectors (0 dimensions) |
| **Sources** | n/a |
| **License** | `MIT` |
| **Author** | [Vishnu Nandakumar](https://github.com/Vishnunkumar/eng_spacysentiment) |

### Label Scheme

<details>

<summary>View label scheme (3 labels for 1 components)</summary>

| Component | Labels |
| --- | --- |
| **`textcat`** | `positive`, `negative`, `neutral` |

</details>